.. mp-api documentation master file, created by
   sphinx-quickstart on Mon Oct  3 13:56:19 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the **mp-api** code documentation! 
==================================
**mp-api** contains the core client implementation for the updated Materials Project API.

This is intended to be barebones documentation for the client classes and their methods.
For more comprehensive documention on how to use the code to access Materials Project data, `see the main updated documentation <https://next-gen-docs.materialsproject.org/downloading-data/how-do-i-download-the-materials-project-database>`_.

Support
-------

If you are having issues, please let us know through `github <https://github.com/materialsproject/api/issues>`_, or `on the MatSci community discourse <https://matsci.org/c/materials-project>`_.

Contents
--------

.. toctree::
   :maxdepth: 2

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
